==> openshift-model-operator-5.12.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/StorageBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageBuilder extends io.fabric8.openshift.api.model.operator.v1.StorageFluentImpl<io.fabric8.openshift.api.model.operator.v1.StorageBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.Storage,io.fabric8.openshift.api.model.operator.v1.StorageBuilder>{
  public StorageBuilder() {
    this(false);
  }
  public StorageBuilder(java.lang.Boolean validationEnabled) {
    this(new Storage(), validationEnabled);
  }
  public StorageBuilder(io.fabric8.openshift.api.model.operator.v1.StorageFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageBuilder(io.fabric8.openshift.api.model.operator.v1.StorageFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Storage(), validationEnabled);
  }
  public StorageBuilder(io.fabric8.openshift.api.model.operator.v1.StorageFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.Storage instance) {
    this(fluent, instance, false);
  }
  public StorageBuilder(io.fabric8.openshift.api.model.operator.v1.StorageFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.Storage instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageBuilder(io.fabric8.openshift.api.model.operator.v1.Storage instance) {
    this(instance,false);
  }
  public StorageBuilder(io.fabric8.openshift.api.model.operator.v1.Storage instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.StorageFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.Storage build() {
    Storage buildable = new Storage(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageBuilder that = (StorageBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.4.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/StorageBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StorageBuilder extends StorageFluentImpl<StorageBuilder> implements VisitableBuilder<Storage,StorageBuilder>{
  public StorageBuilder() {
    this(false);
  }
  public StorageBuilder(Boolean validationEnabled) {
    this(new Storage(), validationEnabled);
  }
  public StorageBuilder(StorageFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageBuilder(StorageFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Storage(), validationEnabled);
  }
  public StorageBuilder(StorageFluent<?> fluent,Storage instance) {
    this(fluent, instance, false);
  }
  public StorageBuilder(StorageFluent<?> fluent,Storage instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageBuilder(Storage instance) {
    this(instance,false);
  }
  public StorageBuilder(Storage instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  StorageFluent<?> fluent;
  Boolean validationEnabled;
  public Storage build() {
    Storage buildable = new Storage(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
